<div align="center">
  <picture>
    <source media="(prefers-color-scheme: dark)" alt="Bookshelf" srcset="https://github.com/mcbookshelf/bookshelf/raw/master/docs/_imgs/banner-dark.png" width="600px">
    <img alt="Bookshelf" src="https://github.com/mcbookshelf/bookshelf/raw/master/docs/_imgs/banner-light.png" width="600px">
  </picture>
</div>

<div align="center">
  <a href="https://github.com/mcbookshelf/bookshelf/stargazers"><img src="https://img.shields.io/github/stars/mcbookshelf/bookshelf?colorA=363a4f&colorB=b7bdf8&style=for-the-badge&logo=data:image/svg+xml;base64, "></a>
  &nbsp;
  <a href="https://github.com/mcbookshelf/bookshelf/releases/latest"><img src="https://img.shields.io/github/v/release/mcbookshelf/bookshelf?colorA=363a4f&colorB=a6da95&style=for-the-badge&logo=github&logoColor=cad3f5"></a>
  &nbsp;
  <a href="https://discord.gg/MkXytNjmBt"><img src="https://img.shields.io/discord/1247513995376726116?style=for-the-badge&color=%237289DA&labelColor=363a4f&logo=discord&logoColor=cad3f5"></a>
</div>

<br/>
<br/>

# 🧱 Bookshelf Block

  Manage blocks, including states and NBTs, while offering advanced tools for seamless transformations.

> "Architecture is the thoughtful making of space."
> — Louis Kahn

## ✨ Features

- **🔍 Get**: Get the block state, NBT data or type and store it into a storage.
- **⚙️ Set**: Set the block state, NBT data or type from a storage to a block.
- **🔄 Transform**: Transform stored block data; mix different block data (for example stone + oak stairs = stone stairs).
- **✅ Check**: Check if a block is a certain type, has a certain NBT data or state.
- **🎨 Produce**: Transform stored and modified data into a new block, display block, sound or particle.

📚 [Read the full documentation](https://docs.mcbookshelf.dev/en/latest/modules/block.html)

## 📖 About Bookshelf

This module is part of the [Bookshelf Library](https://docs.mcbookshelf.dev/en/latest/index.html), a modular collection of Minecraft datapacks built to simplify complex systems and empower mapmakers.

🧩 Find more modules in the [Bookshelf organization](https://modrinth.com/organization/mcbookshelf). \
📦 Get the full suite [Bookshelf Suite](https://modrinth.com/datapack/bookshelf-suite).

## 🤝 Get Involved

💬 Join our [Discord community](https://discord.gg/MkXytNjmBt). \
🛠 Contribute via the [contribution guide](https://docs.mcbookshelf.dev/en/latest/contribute/).
